@@ -2,4 +2,4 @@ from enum import Enum
 
 class CmNodeType(Enum):
     Inferred = 'Inferred'
-    TextBased = 'TaxedBased'
+    TextBased = 'TextBased'
