@@ -190,10 +190,10 @@ class Conversation(TextElement):
         sentences = self.parse_full_text(full_text)
         i = 0
         for contribution in self.components:
-            left = len(contribution.text)
-            while i < len(sentences) and len(sentences[i].text) <= left:
+            left = contribution.text.lstrip()
+            while i < len(sentences) and left.startswith(sentences[i].text):
                 contribution.add_sentence(sentences[i])
-                left -= len(sentences[i].text)
+                left = left[len(sentences[i].text):].lstrip()
                 i += 1
 
 
