@@ -141,7 +141,8 @@ class TransformersEncoder(VectorModel):
             try:
                 self._encode_block(buffer)
             except Exception as e:
-                logger.warning(f"Invalid characters:\n{'\n'.join(x.text for x in buffer)}")
+                text = '\n'.join(x.text for x in buffer)
+                logger.warning("Invalid characters:\n" + text)
             for x in buffer:
                 if self in x.vectors:
                     vectors.append(x.vectors[self].values)
@@ -149,7 +150,8 @@ class TransformersEncoder(VectorModel):
         try:
             self._encode_block(buffer)
         except Exception as e:
-            logger.warning(f"Invalid characters:\n{'\n'.join(x.text for x in buffer)}")
+            text = '\n'.join(x.text for x in buffer)
+            logger.warning("Invalid characters:\n" + text)
         for x in buffer:
             if self in x.vectors:
                 vectors.append(x.vectors[self].values)
